Module codegen

Module codegen 

Code generation module for compiling ELO expressions to Rust

This module provides the core code generation engine that transforms ELO AST into idiomatic Rust code via the quote! macro.

Re-exports

pub use errors::CodeGenError;
pub use operators::BinaryOp;
pub use operators::OperatorGenerator;
pub use operators::UnaryOp;
pub use types::TypeContext;

Modules

ast_to_code
AST-to-Rust code generation visitor
errors
Code generation errors
expressions
Expression code generation
functions
Standard library function call code generation
operators
Binary and unary operator code generation
optimization
Optimization passes for ELO code generation
temporal
Temporal value code generation for dates, times, and durations
type_inference
Type inference system for ELO expressions
types
Type system mapping between ELO and Rust types

Structs

RustCodeGenerator
Main code generator for transforming ELO AST to Rust code