AST-to-Rust code generation visitor
This module implements the Visitor trait to transform ELO AST nodes into Rust TokenStreams that can be compiled.
Structs
- Codegen
Visitor - Visitor that generates Rust code from ELO AST
AST-to-Rust code generation visitor
This module implements the Visitor trait to transform ELO AST nodes into Rust TokenStreams that can be compiled.