Token

Enum Token 

pub enum Token {
Show 61 variants Integer(i64), Float(f64), String(String), True, False, Null, Plus, Minus, Star, Slash, Percent, Caret, Equal, EqualEqual, NotEqual, Less, LessEqual, Greater, GreaterEqual, AndAnd, OrOr, Bang, Let, In, If, Then, Else, Fn, Guard, Now, Today, Tomorrow, Yesterday, StartOfDay, EndOfDay, StartOfWeek, EndOfWeek, StartOfMonth, EndOfMonth, StartOfQuarter, EndOfQuarter, StartOfYear, EndOfYear, BeginningOfTime, EndOfTime, Identifier(String), Dot, Comma, LeftParen, RightParen, LeftBracket, RightBracket, LeftBrace, RightBrace, Colon, Semicolon, Arrow, Pipe, LambdaArrow, Alternative, Eof,
}
A single token in an ELO expression

Variants



Integer(i64)

Integer literal (e.g., 42, -100)



Float(f64)

Float literal (e.g., 3.14, -2.5)



String(String)

String literal (single-quoted, e.g., ‘hello’)



True

Boolean true



False

Boolean false



Null

Null literal



Plus

Plus operator: +



Minus

Minus operator: -



Star

Star operator (multiplication): *



Slash

Slash operator (division): /



Percent

Percent operator (modulo): %



Caret

Caret operator (exponentiation): ^



Equal

Single equals operator: =



EqualEqual

Equal equal operator: ==



NotEqual

Not equal operator: !=



Less

Less than operator: <



LessEqual

Less or equal operator: <=



Greater

Greater than operator: >



GreaterEqual

Greater or equal operator: >=



AndAnd

Logical AND operator: &&



OrOr

Logical OR operator: ||



Bang

Logical NOT operator: !



Let

let keyword



In

in keyword



If

if keyword



Then

then keyword



Else

else keyword



Fn

fn keyword



Guard

guard keyword



Now

NOW keyword



Today

TODAY keyword



Tomorrow

TOMORROW keyword



Yesterday

YESTERDAY keyword



StartOfDay

SOD keyword (start of day)



EndOfDay

EOD keyword (end of day)



StartOfWeek

SOW keyword (start of week)



EndOfWeek

EOW keyword (end of week)



StartOfMonth

SOM keyword (start of month)



EndOfMonth

EOM keyword (end of month)



StartOfQuarter

SOQ keyword (start of quarter)



EndOfQuarter

EOQ keyword (end of quarter)



StartOfYear

SOY keyword (start of year)



EndOfYear

EOY keyword (end of year)



BeginningOfTime

BOT keyword (beginning of time)



EndOfTime

EOT keyword (end of time)



Identifier(String)

Identifier or function name



Dot

Dot operator: .



Comma

Comma: ,



LeftParen

Left parenthesis: (



RightParen

Right parenthesis: )



LeftBracket

Left bracket: [



RightBracket

Right bracket: ]



LeftBrace

Left brace: {



RightBrace

Right brace: }



Colon

Colon: :



Semicolon

Semicolon: ;



Arrow

Arrow operator: =>



Pipe

Pipe operator: |>



LambdaArrow

Lambda arrow: ~>



Alternative

Alternative operator: ?|



Eof

Pipe union: || End of input